@@ -10,9 +10,10 @@ from compas_rhino.geometry import RhinoPoint
 class NodeSearchComponent(component):
     def RunScript(self, diagram, point):
         if point and diagram:
-            node = []
-            for pt in point:
-                pt = RhinoPoint.from_geometry(pt).to_compas()
-                gkey = geometric_key(pt, diagram.tol)
-                node.append(diagram.gkey_node[gkey])
-            return node
+            # node = []
+            # for pt in point:
+            pt = RhinoPoint.from_geometry(point).to_compas()
+            gkey = geometric_key(pt, diagram.tol)
+            # node.append(diagram.gkey_node[gkey])
+            # return node
+            return diagram.gkey_node[gkey]
