@@ -1,20 +1,17 @@
 """
-Build a topology diagram.
+Assemble a topology diagram.
 """
 from ghpythonlib.componentbase import executingcomponent as component
 
 from compas_cem.diagrams import TopologyDiagram
 
 
-class BuildTopologyDiagramComponent(component):
-    def RunScript(self, nodes, trail_edges, deviation_edges, loads, supports):
+class AssembleTopologyDiagramComponent(component):
+    def RunScript(self, trail_edges, deviation_edges, loads, supports, add_auxiliary_trails):
 
+        add_auxiliary_trails = add_auxiliary_trails or False
         topology = TopologyDiagram()
 
-        if nodes:
-            for node in nodes:
-                topology.add_node(node)
-
         if trail_edges:
             for trail_edge in trail_edges:
                 topology.add_edge(trail_edge)
@@ -31,4 +28,7 @@ class BuildTopologyDiagramComponent(component):
             for support in supports:
                 topology.add_support(support)
 
+        if trail_edges and supports:
+            topology.build_trails(add_auxiliary_trails)
+
         return topology
